@@ -17,6 +17,7 @@ from explainaboard.utils.eval_basic_qa import *
 from metric import Accuracy
 from metric import F1score
 from config import BuilderConfig
+from tqdm import tqdm
 
 from eaas import Config, Client
 config = Config()
@@ -90,9 +91,9 @@ class QASquadExplainaboardBuilder:
         :return:
         """
         # Get names of bucketing features
-        print(f"self._info.features.get_bucket_features()\n {self._info.features.get_bucket_features()}")
+        # print(f"self._info.features.get_bucket_features()\n {self._info.features.get_bucket_features()}")
         bucket_features = self._info.features.get_bucket_features()
-        for _id, dict_sysout in enumerate(self._system_output):
+        for _id, dict_sysout in tqdm(enumerate(self._system_output), desc="featurizing"):
             # Get values of bucketing features
             for bucket_feature in bucket_features:
                 feature_value = eval(QASquadExplainaboardBuilder.get_bucket_feature_value(bucket_feature))(dict_sysout)
@@ -155,19 +156,19 @@ class QASquadExplainaboardBuilder:
 
 
         # Bucketing
-        for feature_name in self._info.features.get_bucket_features():
+        for feature_name in tqdm(self._info.features.get_bucket_features(), desc="bucketing"):
 
-            print(f"Feature Name: {feature_name}\n"
-                  f"Bucket Hyper:\n function_name: {self._info.features[feature_name].bucket_info._method} \n"
-                  f"bucket_number: {self._info.features[feature_name].bucket_info._number}\n"
-                  f"bucket_setting: {self._info.features[feature_name].bucket_info._setting}\n")
+            # print(f"Feature Name: {feature_name}\n"
+            #       f"Bucket Hyper:\n function_name: {self._info.features[feature_name].bucket_info._method} \n"
+            #       f"bucket_number: {self._info.features[feature_name].bucket_info._number}\n"
+            #       f"bucket_setting: {self._info.features[feature_name].bucket_info._setting}\n")
 
             self._samples_over_bucket[feature_name] = eval(self._info.features[feature_name].bucket_info._method)(
                                 dict_obj = feature_to_sample_address_to_value[feature_name],
                                 bucket_number = self._info.features[feature_name].bucket_info._number,
                                 bucket_setting = self._info.features[feature_name].bucket_info._setting)
 
-            print(f"self._samples_over_bucket.keys():\n{self._samples_over_bucket.keys()}")
+            # print(f"self._samples_over_bucket.keys():\n{self._samples_over_bucket.keys()}")
 
             # evaluating bucket: get bucket performance
             self._performances_over_bucket[feature_name] = self.get_bucket_performance(feature_name)
@@ -204,7 +205,8 @@ class QASquadExplainaboardBuilder:
                         # bucket_case = {"true_answer": (sample_id, ["true_answers","text"]),
                         #                "predicted_answer": (sample_id, ["predicted_answer"]),
                         #                "question": (sample_id, ["question"])}
-                        bucket_case = str(sample_id)
+                        system_output_id = self._data[int(sample_id)]["id"]
+                        bucket_case = system_output_id
                         bucket_cases.append(bucket_case)
 
             bucket_name_to_performance[bucket_interval] = []
@@ -220,11 +222,11 @@ class QASquadExplainaboardBuilder:
                 confidence_score_up = 0
 
 
-                print(
-                      f"value:\t {bucket_value}\n"
-                      f"confidence low\t {confidence_score_low}\n"
-                      f"confidence up \t {confidence_score_up}\n"
-                      f"---------------------------------")
+                # print(
+                #       f"value:\t {bucket_value}\n"
+                #       f"confidence low\t {confidence_score_low}\n"
+                #       f"confidence up \t {confidence_score_up}\n"
+                #       f"---------------------------------")
 
                 bucket_performance = BucketPerformance(bucket_name=bucket_interval,
                                   metric_name = metric_name,
@@ -267,7 +269,7 @@ class QASquadExplainaboardBuilder:
         eb_generator = self._complete_feature()
         self._bucketing_samples(eb_generator)
         self.get_overall_performance()
-        self._print_bucket_info()
+        # self._print_bucket_info()
         self._generate_report()
         return self._info
 
