@@ -20,6 +20,7 @@ from metric import Accuracy
 from metric import F1score
 from config import BuilderConfig
 import pickle
+from tqdm import tqdm
 
 """
 - [ ] Automatically delete features without pre-trained dict
@@ -62,7 +63,7 @@ class NERExplainaboardBuilder:
         dict_pre_computed_models = {}
         for feature_name in self._info.features.get_pre_computed_features():
             if os.path.exists(self._path_pre_computed_models):
-                print('load the hard dictionary of entity span in test set...')
+                # print('load the hard dictionary of entity span in test set...')
                 # print(self._path_pre_computed_models + "/" + feature_name + ".pkl")
                 fread = open(self._path_pre_computed_models + "/" + feature_name + ".pkl", 'rb')
                 dict_pre_computed_models[feature_name] = pickle.load(fread)
@@ -170,7 +171,7 @@ class NERExplainaboardBuilder:
         # Get names of bucketing features
         # print(f"self._info.features.get_bucket_features()\n {self._info.features.get_bucket_features()}")
         bucket_features = self._info.features.get_bucket_features()
-        for _id, dict_sysout in enumerate(self._system_output):
+        for _id, dict_sysout in tqdm(enumerate(self._system_output), desc="featurizing"):
             # Get values of bucketing features
             tokens = dict_sysout["tokens"]
             true_tags = dict_sysout["true_tags"]
@@ -280,7 +281,7 @@ class NERExplainaboardBuilder:
 
 
         # Bucketing
-        for feature_name in self._info.features.get_bucket_features():
+        for feature_name in tqdm(self._info.features.get_bucket_features(), desc="bucketing"):
 
             _bucket_info = ""
             if feature_name in self._info.features.keys():
@@ -289,10 +290,10 @@ class NERExplainaboardBuilder:
                 # print(self._info.features)
                 _bucket_info = self._info.features["true_entity_info"].feature.feature[feature_name].bucket_info
 
-            print(f"Feature Name: {feature_name}\n"
-                  f"Bucket Hyper:\n function_name: {_bucket_info._method} \n"
-                  f"bucket_number: {_bucket_info._number}\n"
-                  f"bucket_setting: {_bucket_info._setting}\n")
+            # print(f"Feature Name: {feature_name}\n"
+            #       f"Bucket Hyper:\n function_name: {_bucket_info._method} \n"
+            #       f"bucket_number: {_bucket_info._number}\n"
+            #       f"bucket_setting: {_bucket_info._setting}\n")
 
             self._samples_over_bucket_true[feature_name] = eval(_bucket_info._method)(
                                 dict_obj = feature_to_sample_address_to_value_true[feature_name],
@@ -342,6 +343,7 @@ class NERExplainaboardBuilder:
             pred_label = ""
             sent_id = int(pos.split("|||")[0])
             span = pos.split("|||")[-1]
+            system_output_id = self._data[int(sent_id)]["id"]
 
 
             span_sentence = " ".join(self._data[sent_id]["tokens"])
@@ -355,7 +357,7 @@ class NERExplainaboardBuilder:
             #error_case = span+ "|||" + span_sentence + "|||" + true_label + "|||" + pred_label
             error_case = {
                 "span":span,
-                "text":span_sentence,
+                "text":system_output_id,
                 "true_label":true_label,
                 "predicted_label":pred_label,
             }
@@ -369,6 +371,8 @@ class NERExplainaboardBuilder:
             sent_id = int(pos.split("|||")[0])
             span = pos.split("|||")[-1]
             span_sentence = " ".join(self._data[sent_id]["tokens"])
+            system_output_id = self._data[int(sent_id)]["id"]
+            # print(span_sentence)
 
             if pos in dict_pos2tag.keys():
                 true_label = dict_pos2tag[pos]
@@ -379,7 +383,7 @@ class NERExplainaboardBuilder:
             #error_case = span + "|||" + span_sentence + "|||" + true_label + "|||" + pred_label
             error_case = {
                 "span":span,
-                "text":span_sentence,
+                "text":system_output_id,
                 "true_label":true_label,
                 "predicted_label":pred_label,
             }
@@ -455,7 +459,7 @@ class NERExplainaboardBuilder:
         eb_generator = self._complete_feature()
         self._bucketing_samples(eb_generator)
         self.get_overall_performance()
-        self._print_bucket_info()
+        # self._print_bucket_info()
         self._generate_report()
         return self._info
 
