@@ -110,6 +110,9 @@ class SysOutputInfo:
     def to_dict(self) -> dict:
         return asdict(self)
 
+    def to_memory(self):
+        print(json.dumps(self.to_dict()))
+
 
     def _dump_info(self, file):
         """SystemOutputInfo => JSON"""
