@@ -44,6 +44,13 @@ class TextClassificationLoader(Loader):
                              "text": text.strip(),
                              "true_label": true_label.strip(),
                              "predicted_label": predicted_label.strip()})
+        elif self._file_type == FileType.json:
+            for id, info in enumerate(raw_data):
+                text, true_label, predicted_label = info["text"], info["true_label"], info["predicted_label"]
+                data.append({"id": id,
+                             "text": text.strip(),
+                             "true_label": true_label.strip(),
+                             "predicted_label": predicted_label.strip()})
         else:
             raise NotImplementedError
-        return data
\ No newline at end of file
+        return data
