@@ -13,30 +13,35 @@ class TextSummarizationProcessor(Processor):
         "reference": feature.Value("string"),
         "hypothesis": feature.Value("string"),
         "attr_source_len": feature.Value(dtype="float",
+                                         description="length of source document",
                                          is_bucket=True,
                                          bucket_info=feature.BucketInfo(
                                              _method="bucket_attribute_specified_bucket_value",
                                              _number=4,
                                              _setting=())),
         "attr_compression": feature.Value(dtype="float",
+                                          description="compression",
                                          is_bucket=True,
                                          bucket_info=feature.BucketInfo(
                                              _method="bucket_attribute_specified_bucket_value",
                                              _number=4,
                                              _setting=())),
         "attr_copy_len": feature.Value(dtype="float",
+                                       description="copy length",
                                           is_bucket=True,
                                           bucket_info=feature.BucketInfo(
                                               _method="bucket_attribute_specified_bucket_value",
                                               _number=4,
                                               _setting=())),
         "attr_coverage": feature.Value(dtype="float",
+                                       description="coverage",
                                        is_bucket=True,
                                        bucket_info=feature.BucketInfo(
                                            _method="bucket_attribute_specified_bucket_value",
                                            _number=4,
                                            _setting=())),
         "attr_novelty": feature.Value(dtype="float",
+                                      description="novelty",
                                        is_bucket=True,
                                        bucket_info=feature.BucketInfo(
                                            _method="bucket_attribute_specified_bucket_value",
